#include "_MediaBar_.h"
#include "Bitmaps.h"
#include "MPEGPlayer.h"
const uint32	msg_PlayPause = '_Mpp';

const float		kMediaBarInset 	= 1.0;
const float 	kMediaBarHeight	= kMediaBarInset + kPlayButtonSize.y + kMediaBarInset;

_MediaBar_::_MediaBar_(
	BRect		frame,
	VideoWindow	*owner)
		: BView(frame, B_EMPTY_STRING, B_FOLLOW_BOTTOM | B_FOLLOW_LEFT_RIGHT, B_WILL_DRAW)
{
	fOwner = owner;

	BRect buttonRect;
	buttonRect.SetLeftTop(BPoint(kMediaBarInset, kMediaBarInset + 1.0));
	buttonRect.SetRightBottom(buttonRect.LeftTop() + kPlayButtonSize);
	
	fPlayPauseButton = new PlayPauseButton(buttonRect,
										   B_EMPTY_STRING,
										   kPlayButtonBitmapBits, 
										   kPressedPlayButtonBitmapBits, 
										   kDisabledPlayButtonBitmapBits,
										   kPlayingPlayButtonBitmapBits, 
										   kPressedPlayingPlayButtonBitmapBits,
										   kPausedPlayButtonBitmapBits, 
										   kPressedPausedPlayButtonBitmapBits,
										   new BMessage(msg_PlayPause), 
										   ' ', 
										   0, 
										   B_FOLLOW_LEFT | B_FOLLOW_BOTTOM);
	AddChild(fPlayPauseButton);
	fPlayPauseButton->SetPaused();

	BRect sliderRect = Bounds();
	sliderRect.left = buttonRect.right;
	sliderRect.InsetBy(kMediaBarInset * 4, kMediaBarInset);	

	fMediaSlider = new _MediaSlider_(sliderRect, fOwner);
	AddChild(fMediaSlider);

	SetViewColor(ui_color(B_PANEL_BACKGROUND_COLOR));
}


void
_MediaBar_::SetTotalTime(
	bigtime_t	totalTime)
{
	fMediaSlider->SetTotalTime(totalTime);
}


void
_MediaBar_::SetCurTime(
	bigtime_t	curTime)
{
	fMediaSlider->SetCurTime(curTime);
}


void
_MediaBar_::ActionUpdate(
	media_action	action)
{
	switch (action) {
		case MEDIA_PLAY:
			fPlayPauseButton->SetPlaying();
			break;

		case MEDIA_STOP:
			fPlayPauseButton->SetPaused();
			break;

		default:
			break;
	}
}


void
_MediaBar_::AttachedToWindow()
{
	fPlayPauseButton->SetTarget(this);
}


void
_MediaBar_::Draw(
	BRect	updateRect)
{
	BRect		bounds = Bounds();
	rgb_color	viewColor = ViewColor();
	rgb_color	light = {255, 255, 255, 255};
	rgb_color	dark = tint_color(viewColor, B_DARKEN_3_TINT);

	BeginLineArray(4);
	AddLine(bounds.RightTop(), bounds.RightBottom(), dark);
	AddLine(bounds.RightBottom(), bounds.LeftBottom(), dark);
	AddLine(bounds.LeftBottom(), bounds.LeftTop(), light);
	AddLine(bounds.LeftTop(), bounds.RightTop(), light);
	EndLineArray();
}


void
_MediaBar_::MessageReceived(
	BMessage	*message)
{
	switch (message->what) {
		case msg_PlayPause:
			printf("Message Received\n");
			fOwner->Control((fOwner->IsPlaying()) ? MEDIA_STOP : MEDIA_PLAY);
			break;

		default:
			break;
	}
}
